@@ -54,7 +54,7 @@ trap "rm -f $tmp; exit 1" 1 2 11 15
 $dialog \
 --title 'Compile-time options' \
 --separate-output \
---backtitle 'PureFTPd 1.0.5' \
+--backtitle 'PureFTPd 1.0.7' \
 --checklist 'Defaults should be fine for most users' \
 20 78 10 \
 'without-standalone' "Don't compile the standalone server code" off \
@@ -87,6 +87,8 @@ $dialog \
 'with-largefile' "Support for files > 2 Gb (slower)" off \
 'with-uploadscript' "Allow running pure-uploadscript after upload" on \
 'with-virtualhosts' "Allow a distinct content for each IP address" on \
+'with-virtualchroot' "Follow symlinks outside a chroot jail" off \
+'with-diraliases' "Support directory aliases" on \
 2> $tmp
 
 cfgline='';
@@ -97,7 +99,7 @@ done
 $dialog \
 --title 'Compile-time options' \
 --separate-output \
---backtitle 'PureFTPd 1.0.5' \
+--backtitle 'PureFTPd 1.0.7' \
 --radiolist 'Choose a language for server messages' \
 20 78 10 \
 'english' "This is the default" on \
@@ -113,6 +115,7 @@ $dialog \
 'brazilian-portuguese' "Contributed by Roger C. Demetrescu" off \
 'slovak' "Contributed by Robert Varga" off \
 'korean' "Contributed by Im Eunjea" off \
+'swedish' "Contributed by Ulrik Sartipy" off \
 2> $tmp
 
 z=$(cat $tmp)
@@ -120,7 +123,7 @@ cfgline="$cfgline --with-language=$z"
 
 $dialog \
 --title 'Compile-time options' \
---backtitle 'PureFTPd 1.0.5' \
+--backtitle 'PureFTPd 1.0.7' \
 --inputbox 'Installation prefix (/usr/local is not a bad idea)' \
 10 78 \
 '/usr/local' \
@@ -158,7 +161,7 @@ if [ -n "$gauge" ] ; then
   echo 100
 ) | $dialog \
 --title 'Compilation and installation' \
---backtitle 'PureFTPd 1.0.5' \
+--backtitle 'PureFTPd 1.0.7' \
 "$gauge" 'Please wait...' 10 78 10
 else  
   rm -f config.cache
