@@ -4,6 +4,9 @@
 #include "ftpwho-update.h"
 #include "globals.h"
 #include "messages.h"
+#ifdef WITH_DIRALIASES
+# include "diraliases.h"
+#endif
 #ifdef WITH_DMALLOC
 # include <dmalloc.h>
 #endif
@@ -27,7 +30,7 @@ static void antiidle(void)
 
 static void randomdelay(void)
 {
-    usleep(rand() % 15000UL);    
+    usleep(rand() % 15000UL);          /* dummy... no need for arc4 */
 }
 
 /* 
@@ -455,6 +458,9 @@ void parser(void)
                     help_site:
                     
                     addreply_noformat(214, MSG_SITE_HELP CRLF
+# ifdef WITH_DIRALIASES
+                                      " ALIAS" CRLF
+# endif
                                       " CHMOD" CRLF " IDLE");
                     addreply(214, "Pure-FTPd - http://pureftpd.org");
                 } else if (!strcasecmp(arg, "chmod")) {
@@ -485,6 +491,20 @@ void parser(void)
                     dochmod(sitearg2, mode);
                   chmod_wayout:
                     (void) 0;
+# ifdef WITH_DIRALIASES
+                } else if (!strcasecmp(arg, "alias")) {
+                    if (sitearg == NULL || *sitearg == 0) {
+                        print_aliases();
+                    } else {
+                        register const char *alias;
+                        
+                        if ((alias = lookup_alias(sitearg)) == NULL) {
+                            addreply(214, MSG_ALIASES_ALIAS, sitearg, alias);
+                        } else {
+                            addreply(502, MSG_ALIASES_UNKNOWN, sitearg);
+                        }
+                    }
+# endif
                 } else if (*arg != 0) {
                     addreply(500, "SITE %s " MSG_UNKNOWN_EXTENSION, arg);
                 } else {
