@@ -213,7 +213,7 @@ static int pw_mysql_connect(MYSQL ** const id_sql_server)
 static int pw_mysql_simplequery(MYSQL * const id_sql_server,
                                 const char * const query)
 {
-   if (mysql_real_query(id_sql_server, query, strlen(query)) != 0) {
+    if (mysql_real_query(id_sql_server, query, strlen(query)) != 0) {
        return -1;
     }     
     return 0;
@@ -397,7 +397,10 @@ void pw_mysql_check(AuthResult * const result,
         crypto_plain++;
     }
     if (crypto_crypt != 0) {
-        if (strcmp((const char *) crypt(password, spwd), spwd) == 0) {
+        register const char *crypted;
+
+        if ((crypted = (const char *) crypt(password, spwd)) != NULL &&
+            strcmp(crypted, spwd) == 0) {
             goto auth_ok;
         }
     }
