@@ -49,6 +49,10 @@
 # define MESSAGES_LOCALE "fr_FR"
 # include "messages_fr_funny.h"
 
+#elif defined(MESSAGES_SV)
+# define MESSAGES_LOCALE "sv_SE"
+# include "messages_sv.h"
+
 #else
 # define MESSAGES_LOCALE "en_GB"
 # include "messages_en.h"
