@@ -209,3 +209,7 @@
 #define MSG_QUOTA_EXCEEDED "Quota berschritten: %s wird nicht gespeichert."
 #define MSG_AUTH_UNKNOWN "Unbekannte Authentifizierungsmethode."
 #define MSG_PDB_BROKEN "Konnte indizierte puredb-Datei nicht lesen (oder altes Format gefunden) - Versuche pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s is an alias for %s."
+#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
+#define MSG_ALIASES_LIST "The following aliases are available :"
