@@ -209,3 +209,7 @@
 #define MSG_QUOTA_EXCEEDED "Quota depasse: %s ne sera pas sauvegarde"
 #define MSG_AUTH_UNKNOWN "Methode d'authentification inconnue"
 #define MSG_PDB_BROKEN "Impossible de lire le fichier puredb indexe (ou il est dans un vieux format) - Essayez pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s est un raccourci pour %s."
+#define MSG_ALIASES_UNKNOWN "%s est un raccourci inconnu."
+#define MSG_ALIASES_BROKEN_FILE "Le fichier des raccourcis est corrompu"
+#define MSG_ALIASES_LIST "Les raccourcis suivants sont utilisables :"
