@@ -5,7 +5,7 @@
 #define MSG_CANT_OPEN_CNX "Nie mona utworzy poczenia"
 #define MSG_CANT_CREATE_DATA_SOCKET "Nie mona utworzy gniazda dla danych"
 #define MSG_DEBUG_CLIENT_IS "Adres klienta to"
-#define MSG_SYNTAX_ERROR_IP "Bd syntaksy w adresie IP"
+#define MSG_SYNTAX_ERROR_IP "Bd skadni w adresie IP"
 #define MSG_PORT_SUCCESSFUL "komenda PORT powioda si"
 #define MSG_ONLY_IPV4V6 "Tylko IPv4 oraz IPv6 s wspierane (1,2)"
 #define MSG_ONLY_IPV4 "Tylko IPv4 jest wspierane (1)"
@@ -27,7 +27,7 @@
 #define MSG_IDLE_TIME "Czas oczekiwania ustawiony na %lu sekund"
 #define MSG_SITE_HELP "Nastpujce komendy SITE s obsugiwane"
 #define MSG_BAD_CHMOD "Nieprawidowe prawa"
-#define MSG_UNKNOWN_EXTENSION "jest nieznanym rozszeeniem"
+#define MSG_UNKNOWN_EXTENSION "jest nieznanym rozszerzeniem"
 #define MSG_XDBG_OK "komenda XDBG powioda si, aktualny poziom debugowania to %d"
 #define MSG_UNKNOWN_COMMAND "Nieznana komenda"
 #define MSG_TIMEOUT_NOOP "Przekroczony czas oczekiwania (brak operacji w cigu %lu sekund)"
@@ -41,17 +41,17 @@
 #define MSG_CANT_DO_TWICE "Nie mona tego zrobi w aktualnej sesji"
 #define MSG_UNABLE_SECURE_ANON "Nie mona uaktywni bezpiecznego anonimowego FTP"
 #define MSG_BANDWIDTH_RESTRICTED "Twoje zuycie pasma jest ograniczone"
-#define MSG_NO_PASSWORD_NEEDED "Nie potrzebuj adnego hasa drogi, tchliwy anonimie"
-#define MSG_NOTRUST "Wybacz ale nie mona Ci uwa"
+#define MSG_NO_PASSWORD_NEEDED "Nie potrzebuj adnego hasa, mj drogi, tchliwy anonimie"
+#define MSG_NOTRUST "Wybacz ale nie mona Ci ufa"
 #define MSG_WHOAREYOU "Prosz powiedz mi kim jeste"
-#define MSG_AUTH_FAILED "Autentyfikacja niepowioda si, wybacz"
-#define MSG_AUTH_TOOMANY "Zbyt wiele niepowodze podczas autentyfikacji"
+#define MSG_AUTH_FAILED "Uwierzytelnienie nie powiodo si, wybacz"
+#define MSG_AUTH_TOOMANY "Zbyt wiele niepowodze podczas uwierzytelniania"
 #define MSG_NO_HOMEDIR "Katalog domowy jest niedostpny - przerywam"
 #define MSG_NO_HOMEDIR2 "%s nie istnieje lub nie mona go odczyta"
 #define MSG_START_SLASH "Startuje w /"
 #define MSG_USER_GROUP_ACCESS "Uytkownik %s ma grupowy dostp do"
 #define MSG_FXP_SUPPORT "Ten serwer wspiera transfer FXP"
-#define MSG_RATIO "Musisz respektowa radio %u:%u (UL/DL)"
+#define MSG_RATIO "Musisz respektowa wspczynnik %u:%u (wgrane/pobrane)"
 #define MSG_CHROOT_FAILED "Nie mona uaktywni bezpiecznego wizienia chroot()"
 #define MSG_CURRENT_DIR_IS "OK. Aktualny katalog to %s"
 #define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Aktualny, ograniczony katalog to %s"
@@ -90,8 +90,8 @@
 #define MSG_DELE_SUCCESS "Skasowano %s"
 #define MSG_DELE_TOTAL_FAILURE "Nie skasowano adnego pliku"
 #define MSG_LOAD_TOO_HIGH \
-    "Load systemu wynnosi %3.2f w momencie Twojego zalogowanie. Nie pozawalamy\n" \
-    "na ciganie przez anonimowych uytkownikw przy tak duym obcieniu systemu\n" \
+    "Obcienie systemu wynnosio %3.2f w momencie Twojego zalogowania. Nie pozwalamy\n" \
+    "anonimowym uytkownikom na pobieranie plikw przy tak duym obcieniu systemu.\n" \
     "Wgrywanie jest zawsze dozwolone."
 #define MSG_OPEN_FAILURE "Nie mona otworzy %s"
 #define MSG_OPEN_FAILURE2 "Nie mona otworzy tego pliku"
@@ -104,7 +104,7 @@
     "Ten plik zosta wgrany przez anonimowego uytkownika i nie zosta zatwierdzony\n" \
     "przez administratora do cigania."
 #define MSG_RATIO_DENIAL \
-    "Wybacz ale radio wgrywania/cigania to %u:%u .\n" \
+    "Wybacz ale wspczynnik wgrywania/cigania to %u:%u .\n" \
     "Aktualnie wgrae %llu Kb i cigne %llu Kb.\n" \
     "Prosz wgraj jakie dane i sprbuj cign pniej."
 #define MSG_NO_MORE_TO_DOWNLOAD "Nie pozostao nic do cigania"
@@ -142,7 +142,7 @@
 #define MSG_TYPE_8BIT_FAILURE "Tylko 8-bitowe bajty s wspierane, nie yjemy 10 lat temu"
 #define MSG_TYPE_UNKNOWN "Nieznany TYP"
 #define MSG_TYPE_SUCCESS "TYP to aktualnie"
-#define MSG_STRU_FAILURE "Tylko Pliki s wspierane"
+#define MSG_STRU_FAILURE "Tylko Pliki (\"F\"iles) s wspierane"
 #define MSG_MODE_FAILURE "Prosz uyj trybu S(trumieniowego)"
 #define MSG_RENAME_ABORT "Anulowanie poprzedniej operacji zmiany nazwy"
 #define MSG_RENAME_RNFR_SUCCESS "RNFR zaakceptowane - plik istnieje, gotw do przeznaczenia"
@@ -151,7 +151,7 @@
 #define MSG_RENAME_NORNFR "Potrzeba RNFR przed RNTO"
 #define MSG_RENAME_FAILURE "Usuwanie/zmiana nazwy nie powioda si"
 #define MSG_RENAME_SUCCESS "Zmieniono lub przeniesiono plik"
-#define MSG_NO_SUPERSERVER "Prosz uruchom pure-ftpd z super-serwerem (takim jak tcpserver)"
+#define MSG_NO_SUPERSERVER "Prosz uruchom pure-ftpd z serwerem nadrzdnym (takim jak tcpserver)"
 #define MSG_NO_FTP_ACCOUNT "Nie mona znale konta 'ftp'"
 #define MSG_CONF_ERR "Bd konfiguracji"
 #define MSG_NO_VIRTUAL_FILE "Brakuje nazwy pliku wirtualnych uytkownikw"
@@ -164,7 +164,7 @@
 #define MSG_ILLEGAL_PORTS_RANGE "Nieprawidowy przedzia portw"
 #define MSG_ILLEGAL_LS_LIMITS "Nieprawidowy limit 'ls'"
 #define MSG_ILLEGAL_FORCE_PASSIVE "Niepdawidowe IP wymuszone dla pasywnych pocze"
-#define MSG_ILLEGAL_RATIO "Nieprawidowe radio dotyczce cigania/wgrywania"
+#define MSG_ILLEGAL_RATIO "Nieprawidowy wspczynnik dotyczcy cigania/wgrywania"
 #define MSG_ILLEGAL_UID_LIMIT "Nieprawidowy limit uid"
 #define MSG_ILLEGAL_OPTION "Nieznana opcja"
 #define MSG_LDAP_MISSING_BASE "Brakuje LDAPBaseDN w pliku konfiguracyjnym LDAP"
@@ -173,10 +173,10 @@
 #define MSG_WELCOME_TO "Witaj na"
 #define MSG_MAX_USERS "%lu uytkownikw (maksimum) ju zalogowanych, wybacz"
 #define MSG_NB_USERS "Jeste %d uytkownikiem z %d moliwych"
-#define MSG_WELCOME_TIME "Lokalny czas to %02d:%02d oraz load wynosi %3.2f. Port serwera: %u."
+#define MSG_WELCOME_TIME "Lokalny czas: %02d:%02d. Obcienie systemu: %3.2f. Port serwera: %u."
 #define MSG_ANONYMOUS_FTP_ONLY "Wycznie anonimowe FTP jest dozwolone"
-#define MSG_RATIOS_EVERYONE "RATIO OBEJMUJE WSZYSTKICH UYTKOWNIKW :"
-#define MSG_RATIOS_ANONYMOUS "ANONIMOWYCH UYTKOWNIKW OBEJMUJE UL/DL RATIO :"
+#define MSG_RATIOS_EVERYONE "WSPӣCZYNNIK OBEJMUJE WSZYSTKICH UYTKOWNIKW :"
+#define MSG_RATIOS_ANONYMOUS "ANONIMOWYCH UYTKOWNIKW OBEJMUJE WSPӣCZYNNIK UL/DL :"
 #define MSG_RATIOS_RULE "by cign %u Mb, musisz wgra %u Mb danych."
 #define MSG_INFO_IDLE_M "Zostaniesz rozczony po %lu minutach nieaktywnoci."
 #define MSG_INFO_IDLE_S "Zostaniesz rozczony po %lu sekundach nieaktywnoci."
@@ -191,14 +191,14 @@
 #define MSG_NO_ANONYMOUS_LOGIN "To jest prywatny system - Bez anonimowych logowa"
 #define MSG_ANONYMOUS_ANY_PASSWORD "Dowolne haso zadziaa"
 #define MSG_MAX_USERS_IP "Zbyt wiele pocze (%lu) z tego IP"
-#define MSG_ACTIVE_DISABLED "Try aktywny jest zablokowany"
+#define MSG_ACTIVE_DISABLED "Tryb aktywny jest zablokowany"
 #define MSG_TRANSFER_SUCCESSFUL "Przesy pliku zakoczony sukcesem"
 #define MSG_NO_DISK_SPACE "Dysk peny - prosz wgraj pniej"
 #define MSG_OUT_OF_MEMORY "Zabrako pamici"
 #define MSG_SQL_WRONG_PARMS "Bdne parametry SQL"
 #define MSG_ILLEGAL_TRUSTED_IP "Nieprawidowy zaufany adres IP"
 #define MSG_NO_ASCII_RESUME "Wznawianie transferu ASCII nie jest bezpieczne, prosz najpierw usu plik"
-#define MSG_UNKNOWN_ALTLOG "Nieznany format logwt"
+#define MSG_UNKNOWN_ALTLOG "Nieznany format logw"
 #define MSG_ACCOUNT_DISABLED "Nie mona zalogowa si jako [%s] : konto zablokowane"
 #define MSG_ILLEGAL_CONFIG_FILE_SQL "Nieprawidowy plik konfiguracji SQL"
 #define MSG_SQL_MISSING_SERVER "W konfiguracji SQL brakuje serwera"
@@ -208,4 +208,8 @@
 #define MSG_QUOTA_SIZE "%llu Kbajtw uytych (%d%%) - autoryzowano: %llu Kb"
 #define MSG_QUOTA_EXCEEDED "Przekroczona quota: %s nie zostanie zapisany"
 #define MSG_AUTH_UNKNOWN "Nieznana metoda autentyfikacji"
-#define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
+#define MSG_PDB_BROKEN "Nie udao si odczyta indeksowanego pliku puredb (lub wykryto stary format) - Sprbuj uruchomi pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s is an alias for %s."
+#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
+#define MSG_ALIASES_LIST "The following aliases are available :"
