@@ -209,3 +209,7 @@
 #define MSG_QUOTA_EXCEEDED "Cota excedida : %s no ser armazenado"
 #define MSG_AUTH_UNKNOWN "Mtodo de autenticao desconhecido"
 #define MSG_PDB_BROKEN "No foi possvel ler o arquivo indexado do puredb (ou um formato antigo foi detectado) - Experimente pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s is an alias for %s."
+#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
+#define MSG_ALIASES_LIST "The following aliases are available :"
