@@ -208,10 +208,21 @@ static unsigned int pw_zrand(void)
     int fd;
     int ret;
     
-    if ((fd = open("/dev/urandom", O_RDONLY | O_NONBLOCK)) == -1 &&
-        (fd = open("/dev/random", O_RDONLY | O_NONBLOCK)) == -1) {
+    if (
+#ifdef HAVE_DEV_ARANDOM
+        ((fd = open("/dev/arandom", O_RDONLY | O_NONBLOCK)) == -1)
+#elif defined(HAVE_DEV_URANDOM)
+        ((fd = open("/dev/urandom", O_RDONLY | O_NONBLOCK)) == -1)
+#else
+        ((fd = open("/dev/random", O_RDONLY | O_NONBLOCK)) == -1)
+#endif        
+        ) {
         nax:
+#ifdef HAVE_RANDOM
+        return (unsigned int) random();        
+#else
         return (unsigned int) rand();
+#endif
     }
     if (read(fd, &ret, sizeof ret) != (ssize_t) sizeof ret) {
         close(fd);
@@ -224,11 +235,14 @@ static unsigned int pw_zrand(void)
 
 static char *best_crypt(const char * const pwd)
 {
-    static const char crcars[64] =     /* Blowfish */
+    static const char crcars[64] =
         "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789./";
+    register const char *crypted;
     
-    if (strcmp((char *) crypt("test", "$2a$07$1234567890123456789012"),
-        "$2a$07$123456789012345678901uKO4/IReKqBzRzT6YaajGvw20UBdHW7m") == 0) {
+    if ((crypted = (const char *)      /* Blowfish */
+         crypt("test", "$2a$07$1234567890123456789012")) != NULL &&        
+        strcmp(crypted, "$2a$07$123456789012345678901uKO4"
+               "/IReKqBzRzT6YaajGvw20UBdHW7m") == 0) {
         char salt[] = "$2a$07$0000000000000000000000";        
         int c = 28;
         
@@ -238,8 +252,9 @@ static char *best_crypt(const char * const pwd)
         } while (c > 7);
         
         return (char *) crypt(pwd, salt);        
-    } else if (strcmp((char *) crypt("test", "$1$12345678$"),   /* MD5 */
-               "$1$12345678$oEitTZYQtRHfNGmsFvTBA/") == 0) {
+    } else if ((crypted = (const char *)    /* MD5 */
+                crypt("test", "$1$12345678$")) != NULL &&
+               strcmp(crypted, "$1$12345678$oEitTZYQtRHfNGmsFvTBA/") == 0) {
         char salt[] = "$1$00000000";
         int c = 10;
         
@@ -249,8 +264,9 @@ static char *best_crypt(const char * const pwd)
         } while (c > 3);
         
         return (char *) crypt(pwd, salt);
-    } else if (strcmp((char *) crypt("test", "_.../1234"),   /* extended DES */
-               "_.../1234PAPUVmqGzpU") == 0) {
+    } else if ((crypted = (const char *)    /* Extended DES */
+                crypt("test", "_.../1234")) != NULL &&
+               strcmp(crypted, "_.../1234PAPUVmqGzpU") == 0) {
         char salt[] = "_.../0000";
         int c = 8;
         
@@ -261,7 +277,7 @@ static char *best_crypt(const char * const pwd)
         
         return (char *) crypt(pwd, salt);
     }
-    /* simple DES */
+    /* Simple DES */
     {
         char salt[] = "00";
         
@@ -1135,7 +1151,14 @@ static void init_rand(void)
     struct timezone tz;
     
     gettimeofday(&tv, &tz);
+#ifdef HAVE_SRANDOMDEV
+    srandomdev();
+#endif    
+#ifdef HAVE_RANDOM
+    srandom((unsigned int) (tv.tv_sec ^ tv.tv_usec));
+#else
     srand((unsigned int) (tv.tv_sec ^ tv.tv_usec));
+#endif
 }
 
 int main(int argc, char *argv[])
