@@ -39,7 +39,7 @@ int quota_update(Quota * const quota,
     if (hasquota() != 0 || chrooted == 0) {
         return -2;
     }    
-    if ((fd = open(QUOTA_FILE, O_RDWR | O_CREAT | O_NOFOLLOW, 
+    if ((fd = open("/" QUOTA_FILE, O_RDWR | O_CREAT | O_NOFOLLOW, 
                    (mode_t) 0600)) == -1) {
         return -1;
     }
